#!/usr/bin/env node
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "path", "fs", "@clack/prompts", "prettier", "@gluestack/cli-utils"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const args = process.argv.slice(2);
    let supportedArgs = ['--use-npm', '--help', '-h'];
    const path_1 = __importDefault(require("path"));
    const fs_1 = __importDefault(require("fs"));
    const prompts_1 = require("@clack/prompts");
    const prettier_1 = __importDefault(require("prettier"));
    const cli_utils_1 = require("@gluestack/cli-utils");
    function updatePackageJson(projectName) {
        return __awaiter(this, void 0, void 0, function* () {
            let packageJson = JSON.parse(fs_1.default.readFileSync(path_1.default.join(process.cwd(), projectName, 'package.json'), 'utf-8'));
            packageJson.name = projectName;
            const finalPackageJson = yield prettier_1.default.format(JSON.stringify(packageJson), {
                semi: false,
                parser: 'json-stringify',
            });
            fs_1.default.writeFileSync(path_1.default.join(process.cwd(), projectName, 'package.json'), 
            // JSON.stringify(packageJson)
            finalPackageJson);
        });
    }
    function main() {
        return __awaiter(this, void 0, void 0, function* () {
            let projectPath = path_1.default.join(path_1.default.resolve(__dirname, '..'), 'src', 'template');
            let argsInfo = (0, cli_utils_1.getArgsData)(args, supportedArgs);
            let projectName = argsInfo === null || argsInfo === void 0 ? void 0 : argsInfo.projectName;
            let installationMethod = argsInfo === null || argsInfo === void 0 ? void 0 : argsInfo.installationMethod;
            if (projectName === '' || projectName == undefined) {
                projectName = yield (0, prompts_1.text)({
                    message: 'What is the name of your application?',
                    placeholder: 'my-app',
                    defaultValue: 'my-app',
                    // validate(value) {
                    //   if (value.length === 0) return `Value is required!`;
                    // },
                });
                if ((0, prompts_1.isCancel)(projectName)) {
                    (0, prompts_1.cancel)('Operation cancelled.');
                    process.exit(0);
                }
            }
            // copy directory
            const data = fs_1.default.cpSync(projectPath, path_1.default.join(process.cwd(), projectName), {
                recursive: true,
            });
            prompts_1.log.info(` Using \x1b[33m npm install \x1b!`);
            updatePackageJson(projectName);
            (0, cli_utils_1.installDependencies)(projectName, 
            // @ts-ignore
            'npm install');
        });
    }
    main();
});
